/*
 * uhub - A tiny ADC p2p connection hub
 * Copyright (C) 2007, Jan Vidar Krey
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "uhub.h"

static int verbosity = 4;

static const char* prefixes[] =
{
	"FATAL",
	"ERROR",
	"WARN",
	"USER",
	"INFO",
	"DEBUG",
	"TRACE",
	"DUMP",
    "MEM",
	0
};

void hub_set_log_verbosity(int verb)
{
	verbosity = verb;
}

void hub_log(int log_verbosity, const char *format, ...)
{
	static char logmsg[1024];
	static char timestamp[32];
	struct tm *tmp;
	time_t t;
	va_list args;
	

	if (log_verbosity < verbosity)
	{
		t = time(NULL);
		tmp = localtime(&t);
		strftime(timestamp, 32, "%a %e %T", tmp);
		va_start(args, format);
		vsnprintf(logmsg, 1024, format, args);
		va_end(args);
		fprintf(stderr, "%s %5s: %s\n", timestamp, prefixes[log_verbosity], logmsg);
	}
}
